import { EventEmitter, Component, ViewEncapsulation, Input, Output, NgModule } from '@angular/core';
import { MatSliderModule } from '@angular/material/slider';
import { MatDividerModule } from '@angular/material/divider';
import { FormsModule } from '@angular/forms';
import { CommonModule } from '@angular/common';
import { MatListModule } from '@angular/material/list';

class NgxMatRangeSliderComponent {
    constructor() {
        this.isMinValueInit = true;
        this.isMaxValueInit = true;
        this.thumbLabel = true;
        this.minColor = 'accent';
        this.maxColor = 'primary';
        this.showRuler = false;
        this.formatLabel = (v) => v;
        this.output = new EventEmitter();
        this.maxConf = 75;
        this.minConf = 18;
    }
    set max(m) {
        this.maxConf = parseInt(m.toString(), 10);
    }
    get max() {
        return this.maxConf;
    }
    set min(m) {
        this.minConf = parseInt(m.toString(), 10);
    }
    get min() {
        return this.minConf;
    }
    set value(v) {
        this.minValue = v.min;
        this.maxValue = v.max;
    }
    get rulerArray() {
        return [...Array(this.max - this.min).keys()].map(i => i + this.min);
    }
    ngOnInit() {
        if (!this.minValue) {
            this.minValue = this.min;
        }
        if (!this.maxValue) {
            this.maxValue = this.max;
        }
        this.isMinValueInit = (this.minValue === this.min);
        this.isMaxValueInit = (this.maxValue === this.max);
        this.output.emit({ min: this.minValue, max: this.maxValue });
    }
    valueChange() {
        this.output.emit({ min: this.minValue, max: this.maxValue });
    }
    minValueInput(a) {
        this.isMinValueInit = (a.value === this.min);
        if (a.value >= this.maxValue) {
            a.source.value = this.maxValue;
        }
    }
    maxValueInput(a) {
        this.isMaxValueInit = (a.value === this.max);
        if (a.value <= this.minValue) {
            a.source.value = this.minValue;
        }
    }
}
NgxMatRangeSliderComponent.decorators = [
    { type: Component, args: [{
                selector: 'lib-ngx-mat-range-slider',
                template: "<div class=\"full-width ranger-slider\">\n  <mat-slider\n    (change)=\"valueChange()\"\n    (input)=\"minValueInput($event)\"\n    [(ngModel)]=\"minValue\"\n    [color]=\"minColor\"\n    [displayWith]=\"formatLabel\"\n    [max]=\"max\"\n    [min]=\"min\"\n    [thumbLabel]=\"thumbLabel\"\n    class=\"full-width cdk-focused slider-over slider-min-value\"\n    step=\"1\">\n  </mat-slider>\n  <mat-slider\n    (change)=\"valueChange()\"\n    (input)=\"maxValueInput($event)\"\n    [(ngModel)]=\"maxValue\"\n    [color]=\"maxColor\"\n    [displayWith]=\"formatLabel\"\n    [max]=\"max\"\n    [min]=\"min\"\n    [thumbLabel]=\"thumbLabel\"\n    class=\"full-width cdk-focused slider-over slider-max-value\"\n    step=\"1\">\n  </mat-slider>\n  <div class=\"full-width slider-over slider-line-cover-wrapper\">\n    <mat-divider [class]=\"isMinValueInit? 'slider-line-cover-init' : 'slider-line-cover'\"></mat-divider>\n    <mat-divider [class]=\"isMaxValueInit? 'slider-line-cover-init' : 'slider-line-cover'\"></mat-divider>\n  </div>\n\n  <div *ngIf=\"showRuler\" class=\"outer\">\n    <div class=\"middle\">\n      <div *ngFor=\"let key of rulerArray\" class=\"inner\">|</div>\n    </div>\n    <div class=\"middle\">\n      <div *ngFor=\"let key of rulerArray\" class=\"inner\"><span>{{key}}</span></div>\n    </div>\n  </div>\n</div>\n",
                encapsulation: ViewEncapsulation.None,
                styles: [".slider-over{left:0;position:absolute!important;top:16px}mat-slider{padding-left:0;padding-right:0}ngx-mat-range-slider{height:60px}ngx-mat-range-slider .mat-slider-thumb-label{border-radius:50% 50% 0!important;transform:rotate(45deg)!important}ngx-mat-range-slider .mat-slider-thumb-label-text{opacity:1!important;transform:rotate(-45deg)!important}ngx-mat-range-slider .mat-slider-thumb{transform:scale(0)}ngx-mat-range-slider .mat-slider-track-wrapper{background:#66bb6a}ngx-mat-range-slider .slider-min-value .mat-slider-track-fill,ngx-mat-range-slider .slider-min-value .mat-slider-track-fill:focus{background-color:#bdbdbd!important;outline:#bdbdbd;z-index:99}ngx-mat-range-slider .slider-min-value .mat-slider-track-background,ngx-mat-range-slider .slider-min-value .mat-slider-track-background:focus{display:none}ngx-mat-range-slider .slider-max-value .mat-slider-track-background,ngx-mat-range-slider .slider-max-value .mat-slider-track-background:focus{background-color:#bdbdbd!important;outline:#bdbdbd;z-index:99}ngx-mat-range-slider .slider-max-value .mat-slider-track-fill,ngx-mat-range-slider .slider-max-value .mat-slider-track-fill:focus{display:none}ngx-mat-range-slider .slider-line-cover-wrapper{display:table;top:39px;z-index:-1}ngx-mat-range-slider .slider-line-cover-wrapper .slider-line-cover{background-color:#bdbdbd!important;border-bottom:1px solid #bdbdbd!important;display:table-cell;width:50%}ngx-mat-range-slider .slider-line-cover-wrapper .slider-line-cover-init{background-color:#66bb6a!important;border-bottom:1px solid #66bb6a!important;display:table-cell;width:50%}ngx-mat-range-slider div.outer{border-top:2px solid red;display:table;width:100%}ngx-mat-range-slider div.middle:first-of-type{display:table-row;font-size:5px}ngx-mat-range-slider div.middle:nth-of-type(2){display:table-row;font-size:10px}ngx-mat-range-slider div.middle:nth-of-type(2) span{-ms-writing-mode:tb-rl;-webkit-text-orientation:upright;font-size:10px;text-orientation:upright;writing-mode:vertical-rl}ngx-mat-range-slider div.inner{align-content:center;align-items:center;display:table-cell;text-align:center}"]
            },] }
];
NgxMatRangeSliderComponent.propDecorators = {
    minValue: [{ type: Input }],
    maxValue: [{ type: Input }],
    minColor: [{ type: Input }],
    maxColor: [{ type: Input }],
    showRuler: [{ type: Input }],
    formatLabel: [{ type: Input }],
    output: [{ type: Output }],
    max: [{ type: Input }],
    min: [{ type: Input }],
    value: [{ type: Input }]
};

class NgxMatRangeSliderModule {
}
NgxMatRangeSliderModule.decorators = [
    { type: NgModule, args: [{
                declarations: [NgxMatRangeSliderComponent],
                imports: [
                    CommonModule,
                    FormsModule,
                    MatSliderModule,
                    MatDividerModule,
                    MatListModule,
                ],
                exports: [NgxMatRangeSliderComponent]
            },] }
];

/*
 * Public API Surface of ngx-mat-range-slider
 */

/**
 * Generated bundle index. Do not edit.
 */

export { NgxMatRangeSliderComponent, NgxMatRangeSliderModule };
//# sourceMappingURL=ngx-mat-range-slider.js.map
